nengo\_spa\.version
===================

.. automodule:: nengo_spa.version

.. data:: nengo_spa.version.name

   Package name.

.. data:: nengo_spa.version.version_info

   Tuple with version information: *(major, minor, patch)*

.. data:: nengo_spa.version.dev

   Counter for the development version. Will be *None* in release versions.

.. data:: nengo_spa.version.version

   String representation of version information, including the `.dev` version.
